@@ -10,23 +10,25 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.04';
-$DATE = '2003/09/19';
+$VERSION = '0.05';
+$DATE = '2004/04/29';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Text_Column.pm' => [qw(0.04 2003/09/19), 'revised 0.03'],
-    'MANIFEST' => [qw(0.04 2003/09/19), 'generated, replaces 0.03'],
-    'Makefile.PL' => [qw(0.04 2003/09/19), 'generated, replaces 0.03'],
-    'README' => [qw(0.04 2003/09/19), 'generated, replaces 0.03'],
-    'lib/Text/Column.pm' => [qw(1.1 2003/09/19), 'revised 1.09'],
+    'lib/Docs/Site_SVD/Text_Column.pm' => [qw(0.05 2004/04/29), 'revised 0.04'],
+    'MANIFEST' => [qw(0.05 2004/04/29), 'generated, replaces 0.04'],
+    'Makefile.PL' => [qw(0.05 2004/04/29), 'generated, replaces 0.04'],
+    'README' => [qw(0.05 2004/04/29), 'generated, replaces 0.04'],
+    'lib/Text/Column.pm' => [qw(1.11 2004/04/29), 'revised 1.1'],
     't/Text/Column.d' => [qw(0.01 2003/07/27), 'unchanged'],
-    't/Text/Column.pm' => [qw(0.01 2003/07/05), 'unchanged'],
+    't/Text/Column.pm' => [qw(0.04 2004/04/29), 'revised 0.03'],
     't/Text/Column.t' => [qw(0.05 2003/09/15), 'unchanged'],
-    'tlib/File/Package.pm' => [qw(1.12 2003/09/19), 'unchanged'],
-    'tlib/Test/Tech.pm' => [qw(1.14 2003/09/19), 'revised 1.13'],
-    'tlib/Data/Secs2.pm' => [qw(1.14 2003/09/19), 'new'],
+    't/Text/File/Package.pm' => [qw(1.16 2004/04/29), 'new'],
+    't/Text/Test/Tech.pm' => [qw(1.21 2004/04/29), 'new'],
+    't/Text/Data/Secs2.pm' => [qw(1.18 2004/04/29), 'new'],
+    't/Text/Data/SecsPack.pm' => [qw(0.03 2004/04/29), 'new'],
+    't/Text/Data/Startup.pm' => [qw(0.03 2004/04/29), 'new'],
 
 );
 
@@ -53,11 +55,11 @@ use vars qw(%INVENTORY);
 
  Text::Column - Format tables from hashes and arrays suitable for PODs
 
- Revision: C
+ Revision: D
 
- Version: 0.04
+ Version: 0.05
 
- Date: 2003/09/19
+ Date: 2004/04/29
 
  Prepared for: General Public 
 
@@ -103,7 +105,7 @@ by formatting raw array and hash data into tables for inclusion in PODS
 
 =head2 1.3 Document overview.
 
-This document releases Text::Column version 0.04
+This document releases Text::Column version 0.05
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -116,12 +118,14 @@ system file specification.
 
 =head2 3.1 Inventory of materials released.
 
-This document releases the file found
-at the following repository(s):
+This document releases the file 
 
-   http://www.softwarediamonds/packages/Text-Column-0.04
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.04
+ Text-Column-0.05.tar.gz
 
+found at the following repository(s):
+
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
 Restrictions regarding duplication and license provisions
 are as follows:
@@ -188,17 +192,19 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Text_Column.pm                             0.04    2003/09/19 revised 0.03
- MANIFEST                                                     0.04    2003/09/19 generated, replaces 0.03
- Makefile.PL                                                  0.04    2003/09/19 generated, replaces 0.03
- README                                                       0.04    2003/09/19 generated, replaces 0.03
- lib/Text/Column.pm                                           1.1     2003/09/19 revised 1.09
+ lib/Docs/Site_SVD/Text_Column.pm                             0.05    2004/04/29 revised 0.04
+ MANIFEST                                                     0.05    2004/04/29 generated, replaces 0.04
+ Makefile.PL                                                  0.05    2004/04/29 generated, replaces 0.04
+ README                                                       0.05    2004/04/29 generated, replaces 0.04
+ lib/Text/Column.pm                                           1.11    2004/04/29 revised 1.1
  t/Text/Column.d                                              0.01    2003/07/27 unchanged
- t/Text/Column.pm                                             0.01    2003/07/05 unchanged
+ t/Text/Column.pm                                             0.04    2004/04/29 revised 0.03
  t/Text/Column.t                                              0.05    2003/09/15 unchanged
- tlib/File/Package.pm                                         1.12    2003/09/19 unchanged
- tlib/Test/Tech.pm                                            1.14    2003/09/19 revised 1.13
- tlib/Data/Secs2.pm                                           1.14    2003/09/19 new
+ t/Text/File/Package.pm                                       1.16    2004/04/29 new
+ t/Text/Test/Tech.pm                                          1.21    2004/04/29 new
+ t/Text/Data/Secs2.pm                                         1.18    2004/04/29 new
+ t/Text/Data/SecsPack.pm                                      0.03    2004/04/29 new
+ t/Text/Data/Startup.pm                                       0.03    2004/04/29 new
 
 
 =head2 3.3 Changes
@@ -265,6 +271,17 @@ a directory with mode of 666.
 Add the module 'Data::Secs2' in the tlib that provides 'stringify' support
 for the 'Test::Tech' module.
 
+=item Text-Column-0.05
+
+The lastest build of Test::STDmaker expects the test library in the same
+directory as the test script.
+Coordiated with the lastest Test::STDmaker by moving the
+test library from C<tlib> to C<t/Text>, the same directory as the test script
+and deleting the test library File::TestPath program module.
+CPAN software does not expect C<tlib> and does not properly process it.
+
+Minor clean-up on the POD.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -289,18 +306,36 @@ and installation support are as follows:
 
 =item Installation Instructions.
 
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
-   http://www.softwarediamonds/packages/Text-Column-0.04
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.04
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
+Right click on 'Text-Column-0.05.tar.gz' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip Text-Column-0.05.tar.gz
+ tar -xf Text-Column-0.05.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
 
 =item Prerequistes.
 
@@ -391,20 +426,7 @@ extension for a Perl test script file
 =back
 
 =for html
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 
 =cut
 
@@ -415,12 +437,11 @@ __DATA__
 DISTNAME: Text-Column^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.04^
+VERSION : 0.05^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.03^
-REVISION: C^
-
+PREVIOUS_RELEASE: 0.04^
+REVISION: D^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: Format tables from hashes and arrays suitable for PODs^
@@ -434,7 +455,7 @@ SVD_FSPEC: Unix^
 
 REPOSITORY: 
   http://www.softwarediamonds/packages/
-  http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
+  http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 ^
 
 COMPRESS: gzip^
@@ -446,12 +467,15 @@ CHANGE2CURRENT:  ^
 AUTO_REVISE: 
 lib/Text/Column.pm
 t/Text/Column.*
-lib/File/Package.pm => tlib/File/Package.pm
-lib/Test/Tech.pm => tlib/Test/Tech.pm
-lib/Data/Secs2.pm => tlib/Data/Secs2.pm
+lib/File/Package.pm => t/Text/File/Package.pm
+lib/Test/Tech.pm => t/Text/Test/Tech.pm
+lib/Data/Secs2.pm => t/Text/Data/Secs2.pm
+lib/Data/SecsPack.pm => t/Text/Data/SecsPack.pm
+lib/Data/Startup.pm => t/Text/Data/Startup.pm
 ^
 
 PREREQ_PM:  ^
+README_PODS: lib/Text/Column.pm^
 TESTS: t/Text/Column.t^
 EXE_FILES:  ^
 
@@ -518,6 +542,17 @@ a directory with mode of 666.
 Add the module 'Data::Secs2' in the tlib that provides 'stringify' support
 for the 'Test::Tech' module.
 
+\=item Text-Column-0.05
+
+The lastest build of Test::STDmaker expects the test library in the same
+directory as the test script.
+Coordiated with the lastest Test::STDmaker by moving the
+test library from C<tlib> to C<t/Text>, the same directory as the test script
+and deleting the test library File::TestPath program module.
+CPAN software does not expect C<tlib> and does not properly process it.
+
+Minor clean-up on the POD.
+
 \=back
 
 ^
@@ -630,16 +665,35 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 INSTALLATION:
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
 ${REPOSITORY}
+
+Right click on '${DIST_FILE}' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip ${BASE_DIST_FILE}.tar.${COMPRESS_SUFFIX}
+ tar -xf ${BASE_DIST_FILE}.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
 ^
 
 SUPPORT: 603 882-0846 E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -676,20 +730,7 @@ SEE_ALSO:
 
 
 HTML:
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 ^
 ~-~
 
